diff --git a/asdf.asd b/asdf.asd
index 3e9d3e4912696cabc35bb2ce61a6d8c8a8ec0526..25e1d9b51d16799887b4fc78f18beea63504cefc 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.26.17" ;; to be automatically updated by bin/bump-revision
+  :version "2.26.18" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")))
diff --git a/asdf.lisp b/asdf.lisp
index 7f4c3b669665c7a8b4572f1724552de346605ada..2091ca87e7845fb05b92b69d09f6173a903d4e36 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.26.17: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -118,7 +118,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.26.17")
+         (asdf-version "2.26.18")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -1987,6 +1987,10 @@ PREVIOUS-TIME when not null is the time at which the PREVIOUS system was loaded.
 (defmethod find-component ((module module) (name cons))
   (find-component (find-component module (car name)) (cdr name)))
 
+(defmethod find-component ((base component) (actual component))
+  (declare (ignorable base))
+  actual)
+
 
 ;;; component subclasses
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.26.17: Another System Definition Facility.
+;;; This is ASDF 2.26.18: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: